@@ -1,5 +1,5 @@
 '''
-# CDK Construct Libray for AWS XXX
+# AWS CloudWatch Logs Subscription Destination Library
 
 <!--BEGIN STABILITY BANNER-->---
 
@@ -71,7 +71,13 @@ class KinesisDestination(
         :param role: The role to assume to write log events to the destination. Default: - A new Role is created
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(KinesisDestination.__init__)
+            def stub(
+                stream: aws_cdk.aws_kinesis.IStream,
+                *,
+                role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument stream", value=stream, expected_type=type_hints["stream"])
         props = KinesisDestinationProps(role=role)
 
@@ -96,7 +102,12 @@ class KinesisDestination(
         :param _source_log_group: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(KinesisDestination.bind)
+            def stub(
+                scope: aws_cdk.core.Construct,
+                _source_log_group: aws_cdk.aws_logs.ILogGroup,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument _source_log_group", value=_source_log_group, expected_type=type_hints["_source_log_group"])
         return typing.cast(aws_cdk.aws_logs.LogSubscriptionDestinationConfig, jsii.invoke(self, "bind", [scope, _source_log_group]))
@@ -129,7 +140,9 @@ class KinesisDestinationProps:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(KinesisDestinationProps.__init__)
+            def stub(*, role: typing.Optional[aws_cdk.aws_iam.IRole] = None) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument role", value=role, expected_type=type_hints["role"])
         self._values: typing.Dict[str, typing.Any] = {}
         if role is not None:
@@ -191,7 +204,13 @@ class LambdaDestination(
         :param add_permissions: Whether or not to add Lambda Permissions. Default: true
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(LambdaDestination.__init__)
+            def stub(
+                fn: aws_cdk.aws_lambda.IFunction,
+                *,
+                add_permissions: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument fn", value=fn, expected_type=type_hints["fn"])
         options = LambdaDestinationOptions(add_permissions=add_permissions)
 
@@ -216,7 +235,12 @@ class LambdaDestination(
         :param log_group: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(LambdaDestination.bind)
+            def stub(
+                scope: aws_cdk.core.Construct,
+                log_group: aws_cdk.aws_logs.ILogGroup,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument log_group", value=log_group, expected_type=type_hints["log_group"])
         return typing.cast(aws_cdk.aws_logs.LogSubscriptionDestinationConfig, jsii.invoke(self, "bind", [scope, log_group]))
@@ -250,7 +274,9 @@ class LambdaDestinationOptions:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(LambdaDestinationOptions.__init__)
+            def stub(*, add_permissions: typing.Optional[builtins.bool] = None) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument add_permissions", value=add_permissions, expected_type=type_hints["add_permissions"])
         self._values: typing.Dict[str, typing.Any] = {}
         if add_permissions is not None:
